---
title: 'contentfilter:policy'
url: 'https://docs.danami.com/warden/command-line-interface/contentfilter/contentfilter-policy'
markdown: 'https://docs.danami.com/warden/command-line-interface/contentfilter/contentfilter-policy.md'
date: '2026-10-07'
description: 'Configure the content filter policies. // set server wide policy options warden --task=contentfilter:policy // reset a domain policy warden --task=contentfilter:policy --domain=<string> --default=<yes> // reset a mailbox policy warden --task=contentfilter:policy --mailbox=<string&g…'
taxonomy:
  category:
    - docs
  tag:
    - amavis
    - policy
---

[](#)  [ Basics ](https://docs.danami.com/warden/)     [ Command Line Interface ](https://docs.danami.com/warden/command-line-interface)      Contentfilter       contentfilter:policy    

# contentfilter:policy

Configure the content filter policies.

```
// set server wide policy options
warden --task=contentfilter:policy

// reset a domain policy
warden --task=contentfilter:policy --domain=<string> --default=<yes>

// reset a mailbox policy
warden --task=contentfilter:policy --mailbox=<string> --default=<yes>

```

| Option | Value | Default | Description |
|---|---|---|---|
| `--bypass_spam_checks` | <Y\|N> | N | Disable spam filter checking. |
| `--spam_action` | <move\|quarantine\|block\|tag> | move | The action to take when mail is detected as spam. |
| `--spam_lover` | <Y\|N> | N | Receive spam but with alert header line added. Setting this to N to enable the spam kill level option to reject mail over a certain spam level. |
| `--spam_tag2_level` | <digit> | 7 | If spam score is at or above this level then spam-related header fields inserted for local recipients, and X-Spam-Flag and X-Spam-Status bear a YES. |
| `--spam_kill_level` | <digit> | 13 | If spam score is at or above this level then it is rejected. It will not be delivered to the mailbox. |
| `--spam_folder` | <INBOX.Spam\|INBOX.Trash> | INBOX.Spam | The folder to move mail to when a message is considered spam. |
| `--spam_mark_read` | <Y\|N> | N | Mark spam as read after moving it to the spam folder. |
| `--spam_quarantine_cutoff_level` | <digit> | 7 | If spam score is at or above this level then it will not be quarantined. |
| `--spam_subject_tag2` | <string> |  | Tag the subject line of a message that reaches the spam level. |
| `--bypass_virus_checks` | <Y\|N> | N | Disable virus filter checking. |
| `--virus_lover` | <Y\|N> | N | Receive viruses, with alert header line added. |
| `--warnvirusrecip` | <Y\|N> | N | Send a notification to the recipient that a virus was detected. |
| `--virus_admin` | <string> |  | Send virus notifications to this email address. |
| `--bypass_banned_checks` | <Y\|N> | N | Disable banned file filter checking. |
| `--banned_files_lover` | <Y\|N> | N | Receive banned file attachments but with alert header line added. |
| `--warnbannedrecip` | <Y\|N> | N | Send a notification to the recipient that a banned file was detected. |
| `--banned_admin` | <string> |  | Send banned file notifications to this email address. |
| `--banned_rulenames` | <string1,string2> |  | Apply banned rules set by the administrator. |
| `--bypass_header_checks` | <Y\|N> | N | Disable bad header filter checking. |
| `--bad_header_lover` | <Y\|N> |  | Receive bad header email but with alert header line added. |
| `--warnbadhrecip` | <Y\|N> | N | Send a notification to the recipient that a bad header was detected. |
| `--bad_header_admin` | <string> |  | Send bad header notifications to this email address. |
| `--unchecked_lover` | <Y\|N> | Y | Receive unchecked files but with alert header line added. |
| `--message_size_limit` | <digit> |  | The server wide message size limit in bytes. Set to 0 for no size limit. |
| `--whitelist` | <string1,string2> |  | Set the whitelist. A whitlisted sender will be treated as clean. |
| `--whitelist_add` | <string1,string2> |  | Add addresses to the whitelist. |
| `--whitelist_del` | <string1,string2> |  | Remove addresses from the whitelist. |
| `--blacklist` | <string1,string2> |  | Set the blacklist. A blacklisted sender will be treated as spam. |
| `--blacklist_add` | <string1,string2> |  | Add addresses to the blacklist. |
| `--blacklist_del` | <string1,string2> |  | Remove addresses from the blacklist. |
| `--default` | <yes> |  | Reset all settings to their default values. |
| `--reload` | <yes> |  | Reload the service after saving settings. |

## Examples

```
// reset the server wide policy default
warden --task=contentfilter:policy --default=yes --reload=yes

// reset a domains policy default
warden --task=contentfilter:policy --domain=example.com --default=yes

// reset a mailbox policy default
warden --task=contentfilter:policy --mailbox=test@example.com --default=yes
```

## Related Pages

- [Policy Banks](https://docs.danami.com/warden/settings/contentfilter/policy-banks "Policy Banks")
- [Policy Settings](https://docs.danami.com/warden/settings/contentfilter/policy-settings "Policy Settings")
- [Policy Migrator](https://docs.danami.com/warden/settings/contentfilter/policy-migrator "Policy Migrator")
- [Filter Settings](https://docs.danami.com/warden/settings/contentfilter/filter-settings "Filter Settings")
- [Scanner Settings](https://docs.danami.com/warden/settings/contentfilter/scanner-settings "Scanner Settings")

 [](https://docs.danami.com/warden/command-line-interface/contentfilter/contentfilter-policybanks)

---

## Navigation

- Previous: [contentfilter:milter](https://docs.danami.com/warden/command-line-interface/contentfilter/contentfilter-milter.md)
- Next: [contentfilter:policybanks](https://docs.danami.com/warden/command-line-interface/contentfilter/contentfilter-policybanks.md)
